/*
 * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.TimeZoneNamesBundle;

public class TimeZoneNames_lt extends TimeZoneNamesBundle {
    @Override
    protected final Object[][] getContents() {
        final String[] GMT = new String[] {
               "Grinvi\u010do laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Acre = new String[] {
               "Ako standartinis laikas",
               "",
               "Ako vasaros laikas",
               "",
               "Ako laikas",
               "",
            };
        final String[] Apia = new String[] {
               "Apijos \u017eiemos laikas",
               "",
               "Apijos vasaros laikas",
               "",
               "Apijos laikas",
               "",
            };
        final String[] Cook = new String[] {
               "Kuko Sal\u0173 \u017eiemos laikas",
               "",
               "Kuko Sal\u0173 pus\u0117s vasaros laikas",
               "",
               "Kuko Sal\u0173 laikas",
               "",
            };
        final String[] Cuba = new String[] {
               "Kubos \u017eiemos laikas",
               "",
               "Kubos vasaros laikas",
               "",
               "Kubos laikas",
               "",
            };
        final String[] Fiji = new String[] {
               "Fid\u017eio \u017eiemos laikas",
               "",
               "Fid\u017eio vasaros laikas",
               "",
               "Fid\u017eio laikas",
               "",
            };
        final String[] Gulf = new String[] {
               "Persijos \u012flankos laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Hovd = new String[] {
               "Hovdo \u017eiemos laikas",
               "",
               "Hovdo vasaros laikas",
               "",
               "Hovdo laikas",
               "",
            };
        final String[] Iran = new String[] {
               "Irano \u017eiemos laikas",
               "",
               "Irano vasaros laikas",
               "",
               "Irano laikas",
               "",
            };
        final String[] Niue = new String[] {
               "Niuj\u0117 laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Omsk = new String[] {
               "Omsko \u017eiemos laikas",
               "",
               "Omsko vasaros laikas",
               "",
               "Omsko laikas",
               "",
            };
        final String[] Peru = new String[] {
               "Peru \u017eiemos laikas",
               "",
               "Peru vasaros laikas",
               "",
               "Peru laikas",
               "",
            };
        final String[] Truk = new String[] {
               "\u010cuko laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Wake = new String[] {
               "Veiko Salos laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Casey = new String[] {
               "Keisio laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Chile = new String[] {
               "\u010cil\u0117s \u017eiemos laikas",
               "",
               "\u010cil\u0117s vasaros laikas",
               "",
               "\u010cil\u0117s laikas",
               "",
            };
        final String[] China = new String[] {
               "Kinijos \u017eiemos laikas",
               "",
               "Kinijos vasaros laikas",
               "",
               "Kinijos laikas",
               "",
            };
        final String[] Cocos = new String[] {
               "Kokos\u0173 Sal\u0173 laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Davis = new String[] {
               "Deiviso laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] India = new String[] {
               "Indijos laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Japan = new String[] {
               "Japonijos \u017eiemos laikas",
               "",
               "Japonijos vasaros laikas",
               "",
               "Japonijos laikas",
               "",
            };
        final String[] Korea = new String[] {
               "Kor\u0117jos \u017eiemos laikas",
               "",
               "Kor\u0117jos vasaros laikas",
               "",
               "Kor\u0117jos laikas",
               "",
            };
        final String[] Nauru = new String[] {
               "Nauru laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Nepal = new String[] {
               "Nepalo laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Palau = new String[] {
               "Palau laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Samoa = new String[] {
               "Samoa \u017eiemos laikas",
               "",
               "Samoa vasaros laikas",
               "",
               "Samoa laikas",
               "",
            };
        final String[] Syowa = new String[] {
               "Siovos laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tonga = new String[] {
               "Tongos \u017eiemos laikas",
               "",
               "Tongos vasaros laikas",
               "",
               "Tongos laikas",
               "",
            };
        final String[] Yukon = new String[] {
               "Jukono laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Alaska = new String[] {
               "Aliaskos \u017eiemos laikas",
               "",
               "Aliaskos vasaros laikas",
               "",
               "Aliaskos laikas",
               "",
            };
        final String[] Amazon = new String[] {
               "Amazon\u0117s \u017eiemos laikas",
               "",
               "Amazon\u0117s vasaros laikas",
               "",
               "Amazon\u0117s laikas",
               "",
            };
        final String[] Anadyr = new String[] {
               "Anadyr\u0117s \u017eiemos laikas",
               "",
               "Anadyr\u0117s vasaros laikas",
               "",
               "Anadyr\u0117s laikas",
               "",
            };
        final String[] Azores = new String[] {
               "Azor\u0173 Sal\u0173 \u017eiemos laikas",
               "",
               "Azor\u0173 Sal\u0173 vasaros laikas",
               "",
               "Azor\u0173 Sal\u0173 laikas",
               "",
            };
        final String[] Bhutan = new String[] {
               "Butano laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Brunei = new String[] {
               "Brun\u0117jaus Darusalamo laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Easter = new String[] {
               "Velyk\u0173 salos \u017eiemos laikas",
               "",
               "Velyk\u0173 Salos vasaros laikas",
               "",
               "Velyk\u0173 Salos laikas",
               "",
            };
        final String[] Guyana = new String[] {
               "Gajanos laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Israel = new String[] {
               "Izraelio \u017eiemos laikas",
               "",
               "Izraelio vasaros laikas",
               "",
               "Izraelio laikas",
               "",
            };
        final String[] Kosrae = new String[] {
               "Kosraj\u0117 laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mawson = new String[] {
               "Mosono laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Moscow = new String[] {
               "Maskvos \u017eiemos laikas",
               "",
               "Maskvos vasaros laikas",
               "",
               "Maskvos laikas",
               "",
            };
        final String[] Ponape = new String[] {
               "Ponap\u0117s laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Samara = new String[] {
               "Samaros \u017eiemos laikas",
               "",
               "Samaros vasaros laikas",
               "",
               "Samaros laikas",
               "",
            };
        final String[] Tahiti = new String[] {
               "Tahi\u010dio laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Taipei = new String[] {
               "Taip\u0117jaus \u017eiemos laikas",
               "",
               "Taip\u0117jaus vasaros laikas",
               "",
               "Taip\u0117jaus laikas",
               "",
            };
        final String[] Tuvalu = new String[] {
               "Tuvalu laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Vostok = new String[] {
               "Vostoko laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Wallis = new String[] {
               "Voliso ir Fut\u016bnos laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Arabian = new String[] {
               "Arabijos \u017eiemos laikas",
               "",
               "Arabijos vasaros laikas",
               "",
               "Arabijos laikas",
               "",
            };
        final String[] Armenia = new String[] {
               "Arm\u0117nijos \u017eiemos laikas",
               "",
               "Arm\u0117nijos vasaros laikas",
               "",
               "Arm\u0117nijos laikas",
               "",
            };
        final String[] Bolivia = new String[] {
               "Bolivijos laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Chatham = new String[] {
               "\u010catamo \u017eiemos laikas",
               "",
               "\u010catamo vasaros laikas",
               "",
               "\u010catamo laikas",
               "",
            };
        final String[] ETC_UTC = new String[] {
               "pasaulio suderintasis laikas",
               "UTC",
               "",
               "",
               "",
               "",
            };
        final String[] Ecuador = new String[] {
               "Ekvadoro laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Gambier = new String[] {
               "Gambyro laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Georgia = new String[] {
               "Gruzijos \u017eiemos laikas",
               "",
               "Gruzijos vasaros laikas",
               "",
               "Gruzijos laikas",
               "",
            };
        final String[] Irkutsk = new String[] {
               "Irkutsko \u017eiemos laikas",
               "",
               "Irkutsko vasaros laikas",
               "",
               "Irkutsko laikas",
               "",
            };
        final String[] Magadan = new String[] {
               "Magadano \u017eiemos laikas",
               "",
               "Magadano vasaros laikas",
               "",
               "Magadano laikas",
               "",
            };
        final String[] Myanmar = new String[] {
               "Mianmaro laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Norfolk = new String[] {
               "Norfolko Sal\u0173 \u017eiemos laikas",
               "",
               "Norfolko Sal\u0173 vasaros laikas",
               "",
               "Norfolko Sal\u0173 laikas",
               "",
            };
        final String[] Noronha = new String[] {
               "Fernando de Noronjos \u017eiemos laikas",
               "",
               "Fernando de Noronjos vasaros laikas",
               "",
               "Fernando de Noronjos laikas",
               "",
            };
        final String[] Reunion = new String[] {
               "Reunjono laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Rothera = new String[] {
               "Roteros laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Solomon = new String[] {
               "Saliamono Sal\u0173 laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tokelau = new String[] {
               "Tokelau laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Uruguay = new String[] {
               "Urugvajaus \u017eiemos laikas",
               "",
               "Urugvajaus vasaros laikas",
               "",
               "Urugvajaus laikas",
               "",
            };
        final String[] Vanuatu = new String[] {
               "Vanuatu \u017eiemos laikas",
               "",
               "Vanuatu vasaros laikas",
               "",
               "Vanuatu laikas",
               "",
            };
        final String[] Yakutsk = new String[] {
               "Jakutsko \u017eiemos laikas",
               "",
               "Jakutsko vasaros laikas",
               "",
               "Jakutsko laikas",
               "",
            };
        final String[] Atlantic = new String[] {
               "Atlanto \u017eiemos laikas",
               "",
               "Atlanto vasaros laikas",
               "",
               "Atlanto laikas",
               "",
            };
        final String[] Brasilia = new String[] {
               "Brazilijos \u017eiemos laikas",
               "",
               "Brazilijos vasaros laikas",
               "",
               "Brazilijos laikas",
               "",
            };
        final String[] Chamorro = new String[] {
               "\u010camoro laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Colombia = new String[] {
               "Kolumbijos \u017eiemos laikas",
               "",
               "Kolumbijos vasaros laikas",
               "",
               "Kolumbijos laikas",
               "",
            };
        final String[] Falkland = new String[] {
               "Folkland\u0173 Sal\u0173 \u017eiemos laikas",
               "",
               "Folklando Sal\u0173 vasaros laikas",
               "",
               "Folklando Sal\u0173 laikas",
               "",
            };
        final String[] Malaysia = new String[] {
               "Malaizijos laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Maldives = new String[] {
               "Maldyv\u0173 laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mongolia = new String[] {
               "Ulan Batoro \u017eiemos laikas",
               "",
               "Ulan Batoro vasaros laikas",
               "",
               "Ulan Batoro laikas",
               "",
            };
        final String[] Pakistan = new String[] {
               "Pakistano \u017eiemos laikas",
               "",
               "Pakistano vasaros laikas",
               "",
               "Pakistano laikas",
               "",
            };
        final String[] Paraguay = new String[] {
               "Paragvajaus \u017eiemos laikas",
               "",
               "Paragvajaus vasaros laikas",
               "",
               "Paragvajaus laikas",
               "",
            };
        final String[] Pitcairn = new String[] {
               "Pitkerno laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Sakhalin = new String[] {
               "Sachalino \u017eiemos laikas",
               "",
               "Sachalino vasaros laikas",
               "",
               "Sachalino laikas",
               "",
            };
        final String[] Suriname = new String[] {
               "Surinamo laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Argentina = new String[] {
               "Argentinos \u017eiemos laikas",
               "",
               "Argentinos vasaros laikas",
               "",
               "Argentinos laikas",
               "",
            };
        final String[] Christmas = new String[] {
               "Kal\u0117d\u0173 Salos laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Galapagos = new String[] {
               "Galapag\u0173 laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Hong_Kong = new String[] {
               "Honkongo \u017eiemos laikas",
               "",
               "Honkongo vasaros laikas",
               "",
               "Honkongo laikas",
               "",
            };
        final String[] Indochina = new String[] {
               "Indokinijos laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Kamchatka = new String[] {
               "Kam\u010diatkos Petropavlovsko \u017eiemos laikas",
               "",
               "Kam\u010diatkos Petropavlovsko vasaros laikas",
               "",
               "Kam\u010diatkos Petropavlovsko laikas",
               "",
            };
        final String[] Kyrgystan = new String[] {
               "Kirgistano laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Lord_Howe = new String[] {
               "Lordo Hau \u017eiemos laikas",
               "",
               "Lordo Hau vasaros laikas",
               "",
               "Lordo Hau laikas",
               "",
            };
        final String[] Marquesas = new String[] {
               "Markizo Sal\u0173 laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mauritius = new String[] {
               "Mauricijaus \u017eiemos laikas",
               "",
               "Mauricijaus vasaros laikas",
               "",
               "Mauricijaus laikas",
               "",
            };
        final String[] Singapore = new String[] {
               "Singap\u016bro laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Venezuela = new String[] {
               "Venesuelos laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Volgograd = new String[] {
               "Volgogrado \u017eiemos laikas",
               "",
               "Volgogrado vasaros laikas",
               "",
               "Volgogrado laikas",
               "",
            };
        final String[] Azerbaijan = new String[] {
               "Azerbaid\u017eano \u017eiemos laikas",
               "",
               "Azerbaid\u017eano vasaros laikas",
               "",
               "Azerbaid\u017eano laikas",
               "",
            };
        final String[] Bangladesh = new String[] {
               "Banglade\u0161o \u017eiemos laikas",
               "",
               "Banglade\u0161o vasaros laikas",
               "",
               "Banglade\u0161o laikas",
               "",
            };
        final String[] Cape_Verde = new String[] {
               "\u017daliojo Ky\u0161ulio \u017eiemos laikas",
               "",
               "\u017daliojo Ky\u0161ulio vasaros laikas",
               "",
               "\u017daliojo Ky\u0161ulio laikas",
               "",
            };
        final String[] East_Timor = new String[] {
               "Ryt\u0173 Timoro laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Seychelles = new String[] {
               "Sei\u0161eli\u0173 laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tajikistan = new String[] {
               "Tad\u017eikistano laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Uzbekistan = new String[] {
               "Uzbekistano \u017eiemos laikas",
               "",
               "Uzbekistano vasaros laikas",
               "",
               "Uzbekistano laikas",
               "",
            };
        final String[] Afghanistan = new String[] {
               "Afganistano laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Krasnoyarsk = new String[] {
               "Krasnojarsko \u017eiemos laikas",
               "",
               "Krasnojarsko vasaros laikas",
               "",
               "Krasnojarsko laikas",
               "",
            };
        final String[] New_Zealand = new String[] {
               "Naujosios Zelandijos \u017eiemos laikas",
               "",
               "Naujosios Zelandijos vasaros laikas",
               "",
               "Naujosios Zelandijos laikas",
               "",
            };
        final String[] Novosibirsk = new String[] {
               "Novosibirsko \u017eiemos laikas",
               "",
               "Novosibirsko vasaros laikas",
               "",
               "Novosibirsko laikas",
               "",
            };
        final String[] Philippines = new String[] {
               "Filipin\u0173 \u017eiemos laikas",
               "",
               "Filipin\u0173 vasaros laikas",
               "",
               "Filipin\u0173 laikas",
               "",
            };
        final String[] Vladivostok = new String[] {
               "Vladivostoko \u017eiemos laikas",
               "",
               "Vladivostoko vasaros laikas",
               "",
               "Vladivostoko laikas",
               "",
            };
        final String[] Indian_Ocean = new String[] {
               "Indijos vandenyno laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Line_Islands = new String[] {
               "Laino Sal\u0173 laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Newfoundland = new String[] {
               "Niufaundlendo \u017eiemos laikas",
               "",
               "Niufaundlendo vasaros laikas",
               "",
               "Niufaundlendo laikas",
               "",
            };
        final String[] Turkmenistan = new String[] {
               "Turkm\u0117nistano \u017eiemos laikas",
               "",
               "Turkm\u0117nistano vasaros laikas",
               "",
               "Turkm\u0117nistano laikas",
               "",
            };
        final String[] French_Guiana = new String[] {
               "Pranc\u016bzijos Gvianos laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] New_Caledonia = new String[] {
               "Naujosios Kaledonijos \u017eiemos laikas",
               "",
               "Naujosios Kaledonijos vasaros laikas",
               "",
               "Naujosios Kaledonijos laikas",
               "",
            };
        final String[] South_Georgia = new String[] {
               "Piet\u0173 D\u017eord\u017eijos laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Yekaterinburg = new String[] {
               "Jekaterinburgo \u017eiemos laikas",
               "",
               "Jekaterinburgo vasaros laikas",
               "",
               "Jekaterinburgo laikas",
               "",
            };
        final String[] Africa_Central = new String[] {
               "Centrin\u0117s Afrikos laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Africa_Eastern = new String[] {
               "Ryt\u0173 Afrikos laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Africa_Western = new String[] {
               "Vakar\u0173 Afrikos \u017eiemos laikas",
               "",
               "Vakar\u0173 Afrikos vasaros laikas",
               "",
               "Vakar\u0173 Afrikos laikas",
               "",
            };
        final String[] DumontDUrville = new String[] {
               "Diumono d\u2019Urvilio laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Europe_Central = new String[] {
               "Vidurio Europos \u017eiemos laikas",
               "",
               "Vidurio Europos vasaros laikas",
               "",
               "Vidurio Europos laikas",
               "",
            };
        final String[] Europe_Eastern = new String[] {
               "Ryt\u0173 Europos \u017eiemos laikas",
               "",
               "Ryt\u0173 Europos vasaros laikas",
               "",
               "Ryt\u0173 Europos laikas",
               "",
            };
        final String[] Europe_Western = new String[] {
               "Vakar\u0173 Europos \u017eiemos laikas",
               "",
               "Vakar\u0173 Europos vasaros laikas",
               "",
               "Vakar\u0173 Europos laikas",
               "",
            };
        final String[] Mexico_Pacific = new String[] {
               "Meksikos Ramiojo vandenyno \u017eiemos laikas",
               "",
               "Meksikos Ramiojo vandenyno vasaros laikas",
               "",
               "Meksikos Ramiojo vandenyno laikas",
               "",
            };
        final String[] Africa_Southern = new String[] {
               "Piet\u0173 Afrikos laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] America_Central = new String[] {
               "\u0160iaur\u0117s Amerikos centro \u017eiemos laikas",
               "",
               "\u0160iaur\u0117s Amerikos centro vasaros laikas",
               "",
               "\u0160iaur\u0117s Amerikos centro laikas",
               "",
            };
        final String[] America_Eastern = new String[] {
               "\u0160iaur\u0117s Amerikos ryt\u0173 \u017eiemos laikas",
               "",
               "\u0160iaur\u0117s Amerikos ryt\u0173 vasaros laikas",
               "",
               "\u0160iaur\u0117s Amerikos ryt\u0173 laikas",
               "",
            };
        final String[] America_Pacific = new String[] {
               "\u0160iaur\u0117s Amerikos Ramiojo vandenyno \u017eiemos laikas",
               "",
               "\u0160iaur\u0117s Amerikos Ramiojo vandenyno vasaros laikas",
               "",
               "\u0160iaur\u0117s Amerikos Ramiojo vandenyno laikas",
               "",
            };
        final String[] French_Southern = new String[] {
               "Piet\u0173 Pranc\u016bzijos ir antarktinis laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Gilbert_Islands = new String[] {
               "Gilberto Sal\u0173 laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Hawaii_Aleutian = new String[] {
               "Havaj\u0173\u2013Aleut\u0173 \u017eiemos laikas",
               "",
               "Havaj\u0173\u2013Aleut\u0173 vasaros laikas",
               "",
               "Havaj\u0173-Aleut\u0173 laikas",
               "",
            };
        final String[] Phoenix_Islands = new String[] {
               "Fenikso Sal\u0173 laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Pierre_Miquelon = new String[] {
               "Sen Pjero ir Mikelono \u017eiemos laikas",
               "",
               "Sen Pjero ir Mikelono vasaros laikas",
               "",
               "Sen Pjero ir Mikelono laikas",
               "",
            };
        final String[] America_Mountain = new String[] {
               "\u0160iaur\u0117s Amerikos kaln\u0173 \u017eiemos laikas",
               "",
               "\u0160iaur\u0117s Amerikos kaln\u0173 vasaros laikas",
               "",
               "\u0160iaur\u0117s Amerikos kaln\u0173 laikas",
               "",
            };
        final String[] Marshall_Islands = new String[] {
               "Mar\u0161alo Sal\u0173 laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mexico_Northwest = new String[] {
               "\u0160iaur\u0117s Vakar\u0173 Meksikos \u017eiemos laikas",
               "",
               "\u0160iaur\u0117s Vakar\u0173 Meksikos vasaros laikas",
               "",
               "\u0160iaur\u0117s Vakar\u0173 Meksikos laikas",
               "",
            };
        final String[] Papua_New_Guinea = new String[] {
               "Papua Naujosios Gvin\u0117jos laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Australia_Central = new String[] {
               "Centrin\u0117s Australijos \u017eiemos laikas",
               "",
               "Centrin\u0117s Australijos vasaros laikas",
               "",
               "Centrin\u0117s Australijos laikas",
               "",
            };
        final String[] Australia_Eastern = new String[] {
               "Ryt\u0173 Australijos \u017eiemos laikas",
               "",
               "Ryt\u0173 Australijos vasaros laikas",
               "",
               "Ryt\u0173 Australijos laikas",
               "",
            };
        final String[] Australia_Western = new String[] {
               "Vakar\u0173 Australijos \u017eiemos laikas",
               "",
               "Vakar\u0173 Australijos vasaros laikas",
               "",
               "Vakar\u0173 Australijos laikas",
               "",
            };
        final String[] Greenland_Eastern = new String[] {
               "Grenlandijos ryt\u0173 \u017eiemos laikas",
               "",
               "Grenlandijos ryt\u0173 vasaros laikas",
               "",
               "Grenlandijos ryt\u0173 laikas",
               "",
            };
        final String[] Greenland_Western = new String[] {
               "Grenlandijos vakar\u0173 \u017eiemos laikas",
               "",
               "Grenlandijos vakar\u0173 vasaros laikas",
               "",
               "Grenlandijos vakar\u0173 laikas",
               "",
            };
        final String[] Indonesia_Central = new String[] {
               "Centrin\u0117s Indonezijos laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Indonesia_Eastern = new String[] {
               "Ryt\u0173 Indonezijos laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Indonesia_Western = new String[] {
               "Vakar\u0173 Indonezijos laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Kazakhstan_Eastern = new String[] {
               "Ryt\u0173 Kazachstano laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Kazakhstan_Western = new String[] {
               "Vakar\u0173 Kazachstano laikas",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Australia_CentralWestern = new String[] {
               "Centrin\u0117s vakar\u0173 Australijos \u017eiemos laikas",
               "",
               "Centrin\u0117s vakar\u0173 Australijos vasaros laikas",
               "",
               "Centrin\u0117s vakar\u0173 Australijos laikas",
               "",
            };
        final Object[][] data = new Object[][] {
            { "America/Los_Angeles", America_Pacific },
            { "America/Denver", America_Mountain },
            { "America/Phoenix", America_Mountain },
            { "America/Chicago", America_Central },
            { "America/New_York", America_Eastern },
            { "America/Indianapolis", America_Eastern },
            { "Pacific/Honolulu", Hawaii_Aleutian },
            { "America/Anchorage", Alaska },
            { "America/Halifax", Atlantic },
            { "America/Sitka", Alaska },
            { "America/St_Johns", Newfoundland },
            { "Europe/Paris", Europe_Central },
            { "GMT", GMT },
            { "Asia/Jerusalem", Israel },
            { "Asia/Tokyo", Japan },
            { "Europe/Bucharest", Europe_Eastern },
            { "Asia/Shanghai", China },
            { "UTC", ETC_UTC },
            { "ACT", Australia_Central },
            { "AET", Australia_Eastern },
            { "ART", Europe_Eastern },
            { "AST", Alaska },
            { "BET", Brasilia },
            { "BST", Bangladesh },
            { "CAT", Africa_Central },
            { "CNT", Newfoundland },
            { "CST", America_Central },
            { "CTT", China },
            { "EAT", Africa_Eastern },
            { "ECT", Europe_Central },
            { "JST", Japan },
            { "MIT", Apia },
            { "NET", Armenia },
            { "NST", New_Zealand },
            { "PLT", Pakistan },
            { "PNT", America_Mountain },
            { "PRT", Atlantic },
            { "PST", America_Pacific },
            { "SST", Solomon },
            { "CST6CDT", America_Central },
            { "EST5EDT", America_Eastern },
            { "Etc/GMT", GMT },
            { "Etc/UTC", ETC_UTC },
            { "MST7MDT", America_Mountain },
            { "PST8PDT", America_Pacific },
            { "Asia/Aden", Arabian },
            { "Asia/Baku", Azerbaijan },
            { "Asia/Dili", East_Timor },
            { "Asia/Gaza", Europe_Eastern },
            { "Asia/Hovd", Hovd },
            { "Asia/Omsk", Omsk },
            { "Asia/Oral", Kazakhstan_Western },
            { "Asia/Aqtau", Kazakhstan_Western },
            { "Asia/Chita", Yakutsk },
            { "Asia/Dhaka", Bangladesh },
            { "Asia/Dubai", Gulf },
            { "Asia/Kabul", Afghanistan },
            { "Asia/Macau", China },
            { "Asia/Qatar", Arabian },
            { "Asia/Seoul", Korea },
            { "Africa/Juba", Africa_Central },
            { "Africa/Lome", GMT },
            { "Asia/Almaty", Kazakhstan_Eastern },
            { "Asia/Anadyr", Anadyr },
            { "Asia/Aqtobe", Kazakhstan_Western },
            { "Asia/Atyrau", Kazakhstan_Western },
            { "Asia/Beirut", Europe_Eastern },
            { "Asia/Brunei", Brunei },
            { "Asia/Harbin", China },
            { "Asia/Hebron", Europe_Eastern },
            { "Asia/Kuwait", Arabian },
            { "Asia/Manila", Philippines },
            { "Asia/Muscat", Gulf },
            { "Asia/Riyadh", Arabian },
            { "Asia/Saigon", Indochina },
            { "Asia/Taipei", Taipei },
            { "Asia/Tehran", Iran },
            { "Europe/Kiev", Europe_Eastern },
            { "Europe/Oslo", Europe_Central },
            { "Europe/Riga", Europe_Eastern },
            { "Europe/Rome", Europe_Central },
            { "Indian/Mahe", Seychelles },
            { "Pacific/Yap", Truk },
            { "Africa/Accra", GMT },
            { "Africa/Cairo", Europe_Eastern },
            { "Africa/Ceuta", Europe_Central },
            { "Africa/Dakar", GMT },
            { "Africa/Lagos", Africa_Western },
            { "Africa/Tunis", Europe_Central },
            { "America/Adak", Hawaii_Aleutian },
            { "America/Lima", Peru },
            { "America/Nome", Alaska },
            { "Asia/Baghdad", Arabian },
            { "Asia/Bahrain", Arabian },
            { "Asia/Bangkok", Indochina },
            { "Asia/Bishkek", Kyrgystan },
            { "Asia/Colombo", India },
            { "Asia/Irkutsk", Irkutsk },
            { "Asia/Jakarta", Indonesia_Western },
            { "Asia/Karachi", Pakistan },
            { "Asia/Kuching", Malaysia },
            { "Asia/Magadan", Magadan },
            { "Asia/Nicosia", Europe_Eastern },
            { "Asia/Rangoon", Myanmar },
            { "Asia/Tbilisi", Georgia },
            { "Asia/Thimphu", Bhutan },
            { "Asia/Yakutsk", Yakutsk },
            { "Asia/Yerevan", Armenia },
            { "Europe/Malta", Europe_Central },
            { "Europe/Minsk", Moscow },
            { "Europe/Sofia", Europe_Eastern },
            { "Europe/Vaduz", Europe_Central },
            { "Indian/Cocos", Cocos },
            { "Pacific/Apia", Apia },
            { "Pacific/Fiji", Fiji },
            { "Pacific/Guam", Chamorro },
            { "Pacific/Niue", Niue },
            { "Pacific/Truk", Truk },
            { "Pacific/Wake", Wake },
            { "SystemV/AST4", Atlantic },
            { "SystemV/CST6", America_Central },
            { "SystemV/EST5", America_Eastern },
            { "SystemV/MST7", America_Mountain },
            { "SystemV/PST8", Pitcairn },
            { "SystemV/YST9", Gambier },
            { "Africa/Asmera", Africa_Eastern },
            { "Africa/Bamako", GMT },
            { "Africa/Bangui", Africa_Western },
            { "Africa/Banjul", GMT },
            { "Africa/Bissau", GMT },
            { "Africa/Douala", Africa_Western },
            { "Africa/Harare", Africa_Central },
            { "Africa/Kigali", Africa_Central },
            { "Africa/Luanda", Africa_Western },
            { "Africa/Lusaka", Africa_Central },
            { "Africa/Malabo", Africa_Western },
            { "Africa/Maputo", Africa_Central },
            { "Africa/Maseru", Africa_Southern },
            { "Africa/Niamey", Africa_Western },
            { "America/Aruba", Atlantic },
            { "America/Bahia", Brasilia },
            { "America/Belem", Brasilia },
            { "America/Boise", America_Mountain },
            { "America/Jujuy", Argentina },
            { "America/Thule", Atlantic },
            { "Asia/Ashgabat", Turkmenistan },
            { "Asia/Calcutta", India },
            { "Asia/Dushanbe", Tajikistan },
            { "Asia/Jayapura", Indonesia_Eastern },
            { "Asia/Katmandu", Nepal },
            { "Asia/Khandyga", Yakutsk },
            { "Asia/Makassar", Indonesia_Central },
            { "Asia/Qostanay", Kazakhstan_Eastern },
            { "Asia/Sakhalin", Sakhalin },
            { "Asia/Tashkent", Uzbekistan },
            { "Asia/Ust-Nera", Vladivostok },
            { "Europe/Athens", Europe_Eastern },
            { "Europe/Berlin", Europe_Central },
            { "Europe/Dublin",
                new String[] {
                    "Grinvi\u010do laikas",
                    "",
                    "Airijos vasaros laikas",
                    "",
                    "",
                    "",
                }
            },
            { "Europe/Jersey", GMT },
            { "Europe/Lisbon", Europe_Western },
            { "Europe/London",
                new String[] {
                    "Grinvi\u010do laikas",
                    "",
                    "Britanijos vasaros laikas",
                    "",
                    "",
                    "",
                }
            },
            { "Europe/Madrid", Europe_Central },
            { "Europe/Monaco", Europe_Central },
            { "Europe/Moscow", Moscow },
            { "Europe/Prague", Europe_Central },
            { "Europe/Samara", Samara },
            { "Europe/Skopje", Europe_Central },
            { "Europe/Tirane", Europe_Central },
            { "Europe/Vienna", Europe_Central },
            { "Europe/Warsaw", Europe_Central },
            { "Europe/Zagreb", Europe_Central },
            { "Europe/Zurich", Europe_Central },
            { "Indian/Chagos", Indian_Ocean },
            { "Indian/Comoro", Africa_Eastern },
            { "Pacific/Efate", Vanuatu },
            { "Pacific/Nauru", Nauru },
            { "Pacific/Palau", Palau },
            { "SystemV/HST10", Hawaii_Aleutian },
            { "Africa/Abidjan", GMT },
            { "Africa/Algiers", Europe_Central },
            { "Africa/Conakry", GMT },
            { "Africa/Kampala", Africa_Eastern },
            { "Africa/Mbabane", Africa_Southern },
            { "Africa/Nairobi", Africa_Eastern },
            { "Africa/Tripoli", Europe_Eastern },
            { "America/Belize", America_Central },
            { "America/Bogota", Colombia },
            { "America/Cancun", America_Eastern },
            { "America/Cayman", America_Eastern },
            { "America/Cuiaba", Amazon },
            { "America/Dawson", Yukon },
            { "America/Guyana", Guyana },
            { "America/Havana", Cuba },
            { "America/Inuvik", America_Mountain },
            { "America/Juneau", Alaska },
            { "America/La_Paz", Bolivia },
            { "America/Maceio", Brasilia },
            { "America/Manaus", Amazon },
            { "America/Merida", America_Central },
            { "America/Nassau", America_Eastern },
            { "America/Panama", America_Eastern },
            { "America/Recife", Brasilia },
            { "America/Regina", America_Central },
            { "Asia/Chongqing", China },
            { "Asia/Hong_Kong", Hong_Kong },
            { "Asia/Kamchatka", Kamchatka },
            { "Asia/Pontianak", Indonesia_Western },
            { "Asia/Pyongyang", Korea },
            { "Asia/Qyzylorda", Kazakhstan_Western },
            { "Asia/Samarkand", Uzbekistan },
            { "Asia/Singapore", Singapore },
            { "Asia/Vientiane", Indochina },
            { "Europe/Andorra", Europe_Central },
            { "Europe/Belfast",
                new String[] {
                    "Grinvi\u010do laikas",
                    "",
                    "Britanijos vasaros laikas",
                    "",
                    "",
                    "",
                }
            },
            { "Europe/Tallinn", Europe_Eastern },
            { "Europe/Vatican", Europe_Central },
            { "Europe/Vilnius", Europe_Eastern },
            { "Indian/Mayotte", Africa_Eastern },
            { "Indian/Reunion", Reunion },
            { "Pacific/Easter", Easter },
            { "Pacific/Kosrae", Kosrae },
            { "Pacific/Majuro", Marshall_Islands },
            { "Pacific/Midway", Samoa },
            { "Pacific/Noumea", New_Caledonia },
            { "Pacific/Ponape", Ponape },
            { "Pacific/Saipan", Chamorro },
            { "Pacific/Tahiti", Tahiti },
            { "Pacific/Tarawa", Gilbert_Islands },
            { "Pacific/Wallis", Wallis },
            { "Africa/Blantyre", Africa_Central },
            { "Africa/Djibouti", Africa_Eastern },
            { "Africa/Freetown", GMT },
            { "Africa/Gaborone", Africa_Central },
            { "Africa/Khartoum", Africa_Central },
            { "Africa/Kinshasa", Africa_Western },
            { "Africa/Monrovia", GMT },
            { "Africa/Ndjamena", Africa_Western },
            { "Africa/Sao_Tome", GMT },
            { "Africa/Timbuktu", GMT },
            { "Africa/Windhoek", Africa_Central },
            { "America/Antigua", Atlantic },
            { "America/Caracas", Venezuela },
            { "America/Cayenne", French_Guiana },
            { "America/Cordoba", Argentina },
            { "America/Creston", America_Mountain },
            { "America/Curacao", Atlantic },
            { "America/Detroit", America_Eastern },
            { "America/Godthab", Greenland_Western },
            { "America/Grenada", Atlantic },
            { "America/Iqaluit", America_Eastern },
            { "America/Jamaica", America_Eastern },
            { "America/Managua", America_Central },
            { "America/Marigot", Atlantic },
            { "America/Mendoza", Argentina },
            { "America/Moncton", Atlantic },
            { "America/Nipigon", America_Eastern },
            { "America/Noronha", Noronha },
            { "America/Ojinaga", America_Central },
            { "America/Tijuana", America_Pacific },
            { "America/Toronto", America_Eastern },
            { "America/Tortola", Atlantic },
            { "America/Yakutat", Alaska },
            { "Asia/Choibalsan", Mongolia },
            { "Asia/Phnom_Penh", Indochina },
            { "Atlantic/Azores", Azores },
            { "Atlantic/Canary", Europe_Western },
            { "Atlantic/Faeroe", Europe_Western },
            { "Australia/Eucla", Australia_CentralWestern },
            { "Australia/Perth", Australia_Western },
            { "Europe/Belgrade", Europe_Central },
            { "Europe/Brussels", Europe_Central },
            { "Europe/Budapest", Europe_Central },
            { "Europe/Busingen", Europe_Central },
            { "Europe/Chisinau", Europe_Eastern },
            { "Europe/Guernsey", GMT },
            { "Europe/Helsinki", Europe_Eastern },
            { "Europe/Sarajevo", Europe_Central },
            { "Europe/Uzhgorod", Europe_Eastern },
            { "Indian/Maldives", Maldives },
            { "Pacific/Chatham", Chatham },
            { "Pacific/Fakaofo", Tokelau },
            { "Pacific/Gambier", Gambier },
            { "Pacific/Norfolk", Norfolk },
            { "SystemV/AST4ADT", Atlantic },
            { "SystemV/CST6CDT", America_Central },
            { "SystemV/EST5EDT", America_Eastern },
            { "SystemV/MST7MDT", America_Mountain },
            { "SystemV/PST8PDT", America_Pacific },
            { "SystemV/YST9YDT", Alaska },
            { "Africa/Bujumbura", Africa_Central },
            { "Africa/Mogadishu", Africa_Eastern },
            { "America/Anguilla", Atlantic },
            { "America/Asuncion", Paraguay },
            { "America/Barbados", Atlantic },
            { "America/Dominica", Atlantic },
            { "America/Edmonton", America_Mountain },
            { "America/Eirunepe", Acre },
            { "America/Mazatlan", Mexico_Pacific },
            { "America/Miquelon", Pierre_Miquelon },
            { "America/Montreal", America_Eastern },
            { "America/Resolute", America_Central },
            { "America/Santarem", Brasilia },
            { "America/Santiago", Chile },
            { "America/Shiprock", America_Mountain },
            { "America/St_Kitts", Atlantic },
            { "America/St_Lucia", Atlantic },
            { "America/Winnipeg", America_Central },
            { "Antarctica/Casey", Casey },
            { "Antarctica/Davis", Davis },
            { "Antarctica/Syowa", Syowa },
            { "Antarctica/Troll", GMT },
            { "Asia/Krasnoyarsk", Krasnoyarsk },
            { "Asia/Novosibirsk", Novosibirsk },
            { "Asia/Ulaanbaatar", Mongolia },
            { "Asia/Vladivostok", Vladivostok },
            { "Atlantic/Bermuda", Atlantic },
            { "Atlantic/Madeira", Europe_Western },
            { "Atlantic/Stanley", Falkland },
            { "Australia/Currie", Australia_Eastern },
            { "Australia/Darwin", Australia_Central },
            { "Australia/Hobart", Australia_Eastern },
            { "Australia/Sydney", Australia_Eastern },
            { "Europe/Amsterdam", Europe_Central },
            { "Europe/Gibraltar", Europe_Central },
            { "Europe/Ljubljana", Europe_Central },
            { "Europe/Mariehamn", Europe_Eastern },
            { "Europe/Podgorica", Europe_Central },
            { "Europe/Stockholm", Europe_Central },
            { "Europe/Volgograd", Volgograd },
            { "Indian/Christmas", Christmas },
            { "Indian/Kerguelen", French_Southern },
            { "Indian/Mauritius", Mauritius },
            { "Pacific/Auckland", New_Zealand },
            { "Pacific/Funafuti", Tuvalu },
            { "Pacific/Johnston", Hawaii_Aleutian },
            { "Pacific/Pitcairn", Pitcairn },
            { "Africa/Libreville", Africa_Western },
            { "Africa/Lubumbashi", Africa_Central },
            { "Africa/Nouakchott", GMT },
            { "Africa/Porto-Novo", Africa_Western },
            { "America/Araguaina", Brasilia },
            { "America/Boa_Vista", Amazon },
            { "America/Catamarca", Argentina },
            { "America/Chihuahua", America_Central },
            { "America/Fortaleza", Brasilia },
            { "America/Glace_Bay", Atlantic },
            { "America/Goose_Bay", Atlantic },
            { "America/Guatemala", America_Central },
            { "America/Guayaquil", Ecuador },
            { "America/Matamoros", America_Central },
            { "America/Menominee", America_Central },
            { "America/Monterrey", America_Central },
            { "America/Sao_Paulo", Brasilia },
            { "America/St_Thomas", Atlantic },
            { "America/Vancouver", America_Pacific },
            { "Antarctica/Mawson", Mawson },
            { "Antarctica/Vostok", Vostok },
            { "Asia/Kuala_Lumpur", Malaysia },
            { "Asia/Novokuznetsk", Krasnoyarsk },
            { "Europe/Bratislava", Europe_Central },
            { "Europe/Copenhagen", Europe_Central },
            { "Europe/Luxembourg", Europe_Central },
            { "Europe/San_Marino", Europe_Central },
            { "Europe/Simferopol", Moscow },
            { "Europe/Zaporozhye", Europe_Eastern },
            { "Pacific/Enderbury", Phoenix_Islands },
            { "Pacific/Galapagos", Galapagos },
            { "Pacific/Kwajalein", Marshall_Islands },
            { "Pacific/Marquesas", Marquesas },
            { "Pacific/Pago_Pago", Samoa },
            { "Pacific/Rarotonga", Cook },
            { "Pacific/Tongatapu", Tonga },
            { "Africa/Addis_Ababa", Africa_Eastern },
            { "Africa/Brazzaville", Africa_Western },
            { "Africa/Ouagadougou", GMT },
            { "America/Costa_Rica", America_Central },
            { "America/Grand_Turk", America_Eastern },
            { "America/Guadeloupe", Atlantic },
            { "America/Hermosillo", Mexico_Pacific },
            { "America/Kralendijk", Atlantic },
            { "America/Louisville", America_Eastern },
            { "America/Martinique", Atlantic },
            { "America/Metlakatla", Alaska },
            { "America/Montevideo", Uruguay },
            { "America/Montserrat", Atlantic },
            { "America/Paramaribo", Suriname },
            { "America/Rio_Branco", Acre },
            { "America/St_Vincent", Atlantic },
            { "America/Whitehorse", Yukon },
            { "Antarctica/McMurdo", New_Zealand },
            { "Antarctica/Rothera", Rothera },
            { "Asia/Yekaterinburg", Yekaterinburg },
            { "Atlantic/Jan_Mayen", Europe_Central },
            { "Atlantic/Reykjavik", GMT },
            { "Atlantic/St_Helena", GMT },
            { "Australia/Adelaide", Australia_Central },
            { "Australia/Brisbane", Australia_Eastern },
            { "Australia/Lindeman", Australia_Eastern },
            { "Europe/Isle_of_Man", GMT },
            { "Europe/Kaliningrad", Europe_Eastern },
            { "Pacific/Kiritimati", Line_Islands },
            { "Africa/Johannesburg", Africa_Southern },
            { "America/El_Salvador", America_Central },
            { "America/Fort_Nelson", America_Mountain },
            { "America/Mexico_City", America_Central },
            { "America/Pangnirtung", America_Eastern },
            { "America/Porto_Velho", Amazon },
            { "America/Puerto_Rico", Atlantic },
            { "America/Rainy_River", America_Central },
            { "America/Tegucigalpa", America_Central },
            { "America/Thunder_Bay", America_Eastern },
            { "America/Yellowknife", America_Mountain },
            { "Arctic/Longyearbyen", Europe_Central },
            { "Atlantic/Cape_Verde", Cape_Verde },
            { "Australia/Lord_Howe", Lord_Howe },
            { "Australia/Melbourne", Australia_Eastern },
            { "Indian/Antananarivo", Africa_Eastern },
            { "Pacific/Guadalcanal", Solomon },
            { "Africa/Dar_es_Salaam", Africa_Eastern },
            { "America/Blanc-Sablon", Atlantic },
            { "America/Buenos_Aires", Argentina },
            { "America/Campo_Grande", Amazon },
            { "America/Danmarkshavn", GMT },
            { "America/Dawson_Creek", America_Mountain },
            { "America/Indiana/Knox", America_Central },
            { "America/Rankin_Inlet", America_Central },
            { "America/Santa_Isabel", Mexico_Northwest },
            { "America/Scoresbysund", Greenland_Eastern },
            { "Antarctica/Macquarie", Australia_Eastern },
            { "Pacific/Port_Moresby", Papua_New_Guinea },
            { "America/Cambridge_Bay", America_Mountain },
            { "America/Ciudad_Juarez", America_Mountain },
            { "America/Coral_Harbour", America_Eastern },
            { "America/Indiana/Vevay", America_Eastern },
            { "America/Lower_Princes", Atlantic },
            { "America/Port_of_Spain", Atlantic },
            { "America/Santo_Domingo", Atlantic },
            { "America/St_Barthelemy", Atlantic },
            { "America/Swift_Current", America_Central },
            { "Antarctica/South_Pole", New_Zealand },
            { "Australia/Broken_Hill", Australia_Central },
            { "America/Bahia_Banderas", America_Central },
            { "America/Port-au-Prince", America_Eastern },
            { "Atlantic/South_Georgia", South_Georgia },
            { "America/Argentina/Salta", Argentina },
            { "America/Indiana/Marengo", America_Eastern },
            { "America/Indiana/Winamac", America_Eastern },
            { "America/Argentina/Tucuman", Argentina },
            { "America/Argentina/Ushuaia", Argentina },
            { "America/Indiana/Tell_City", America_Central },
            { "America/Indiana/Vincennes", America_Eastern },
            { "Antarctica/DumontDUrville", DumontDUrville },
            { "timezone.excity.Asia/Aden", "Adenas" },
            { "timezone.excity.Asia/Baku", "Baku" },
            { "timezone.excity.Asia/Dili", "Dilis" },
            { "timezone.excity.Asia/Gaza", "Gazos ruo\u017eas" },
            { "timezone.excity.Asia/Hovd", "Hovdas" },
            { "timezone.excity.Asia/Omsk", "Omskas" },
            { "timezone.excity.Asia/Oral", "Uralskas" },
            { "America/Argentina/La_Rioja", Argentina },
            { "America/Argentina/San_Juan", Argentina },
            { "America/Argentina/San_Luis", Argentina },
            { "America/Indiana/Petersburg", America_Eastern },
            { "timezone.excity.Asia/Amman", "Amanas" },
            { "timezone.excity.Asia/Aqtau", "Aktau" },
            { "timezone.excity.Asia/Chita", "\u010cita" },
            { "timezone.excity.Asia/Dhaka", "Daka" },
            { "timezone.excity.Asia/Dubai", "Dubajus" },
            { "timezone.excity.Asia/Kabul", "Kabulas" },
            { "timezone.excity.Asia/Macau", "Makao" },
            { "timezone.excity.Asia/Qatar", "Kataras" },
            { "timezone.excity.Asia/Seoul", "Seulas" },
            { "timezone.excity.Asia/Tokyo", "Tokijas" },
            { "timezone.excity.Asia/Tomsk", "Tomskas" },
            { "America/Kentucky/Monticello", America_Eastern },
            { "America/North_Dakota/Beulah", America_Central },
            { "America/North_Dakota/Center", America_Central },
            { "timezone.excity.Africa/Juba", "D\u017euba" },
            { "timezone.excity.Africa/Lome", "Lom\u0117" },
            { "timezone.excity.Asia/Almaty", "Alma Ata" },
            { "timezone.excity.Asia/Anadyr", "Anadyris" },
            { "timezone.excity.Asia/Aqtobe", "Aktiubinskas" },
            { "timezone.excity.Asia/Atyrau", "Atyrau" },
            { "timezone.excity.Asia/Beirut", "Beirutas" },
            { "timezone.excity.Asia/Brunei", "Brun\u0117jus" },
            { "timezone.excity.Asia/Hebron", "Hebronas" },
            { "timezone.excity.Asia/Kuwait", "Kuveitas" },
            { "timezone.excity.Asia/Manila", "Manila" },
            { "timezone.excity.Asia/Muscat", "Maskatas" },
            { "timezone.excity.Asia/Riyadh", "Rijadas" },
            { "timezone.excity.Asia/Saigon", "Ho\u0161iminas" },
            { "timezone.excity.Asia/Taipei", "Taip\u0117jus" },
            { "timezone.excity.Asia/Tehran", "Teheranas" },
            { "timezone.excity.Asia/Urumqi", "Urum\u010di" },
            { "timezone.excity.Etc/Unknown", "ne\u017einomas miestas" },
            { "timezone.excity.Europe/Kiev", "Kijevas" },
            { "timezone.excity.Europe/Oslo", "Oslas" },
            { "timezone.excity.Europe/Riga", "Ryga" },
            { "timezone.excity.Europe/Rome", "Roma" },
            { "timezone.excity.Indian/Mahe", "Mah\u0117" },
            { "timezone.excity.Africa/Accra", "Akra" },
            { "timezone.excity.Africa/Cairo", "Kairas" },
            { "timezone.excity.Africa/Ceuta", "Seuta" },
            { "timezone.excity.Africa/Dakar", "Dakaras" },
            { "timezone.excity.Africa/Lagos", "Lagosas" },
            { "timezone.excity.Africa/Tunis", "Tunisas" },
            { "timezone.excity.America/Adak", "Eidakas" },
            { "timezone.excity.America/Lima", "Lima" },
            { "timezone.excity.America/Nome", "Nomas" },
            { "timezone.excity.Asia/Baghdad", "Bagdadas" },
            { "timezone.excity.Asia/Bahrain", "Bahreinas" },
            { "timezone.excity.Asia/Bangkok", "Bankokas" },
            { "timezone.excity.Asia/Barnaul", "Barnaulas" },
            { "timezone.excity.Asia/Bishkek", "Bi\u0161kekas" },
            { "timezone.excity.Asia/Colombo", "Kolombas" },
            { "timezone.excity.Asia/Irkutsk", "Irkutskas" },
            { "timezone.excity.Asia/Jakarta", "D\u017eakarta" },
            { "timezone.excity.Asia/Karachi", "Kara\u010dis" },
            { "timezone.excity.Asia/Kuching", "Ku\u010dingas" },
            { "timezone.excity.Asia/Magadan", "Magadanas" },
            { "timezone.excity.Asia/Nicosia", "Nikosija" },
            { "timezone.excity.Asia/Rangoon", "Rang\u016bnas" },
            { "timezone.excity.Asia/Tbilisi", "Tbilisis" },
            { "timezone.excity.Asia/Thimphu", "Timpu" },
            { "timezone.excity.Asia/Yakutsk", "Jakutskas" },
            { "timezone.excity.Asia/Yerevan", "Jerevanas" },
            { "timezone.excity.Europe/Kirov", "Kirovas" },
            { "timezone.excity.Europe/Malta", "Malta" },
            { "timezone.excity.Europe/Minsk", "Minskas" },
            { "timezone.excity.Europe/Paris", "Pary\u017eius" },
            { "timezone.excity.Europe/Sofia", "Sofija" },
            { "timezone.excity.Europe/Vaduz", "Vaducas" },
            { "timezone.excity.Indian/Cocos", "Kokos\u0173 sala" },
            { "timezone.excity.Pacific/Apia", "Apija" },
            { "timezone.excity.Pacific/Fiji", "Fid\u017eis" },
            { "timezone.excity.Pacific/Guam", "Guamas" },
            { "timezone.excity.Pacific/Niue", "Niuj\u0117" },
            { "timezone.excity.Pacific/Truk", "\u010cukas" },
            { "timezone.excity.Pacific/Wake", "Veiko sala" },
            { "timezone.excity.Africa/Bamako", "Bamakas" },
            { "timezone.excity.Africa/Bangui", "Bangis" },
            { "timezone.excity.Africa/Banjul", "Band\u017eulis" },
            { "timezone.excity.Africa/Bissau", "Bisau" },
            { "timezone.excity.Africa/Douala", "Duala" },
            { "timezone.excity.Africa/Harare", "Harar\u0117" },
            { "timezone.excity.Africa/Kigali", "Kigalis" },
            { "timezone.excity.Africa/Luanda", "Luanda" },
            { "timezone.excity.Africa/Lusaka", "Lusaka" },
            { "timezone.excity.Africa/Malabo", "Malabas" },
            { "timezone.excity.Africa/Maputo", "Maputas" },
            { "timezone.excity.Africa/Maseru", "Maseru" },
            { "timezone.excity.Africa/Niamey", "Niam\u0117jus" },
            { "timezone.excity.America/Aruba", "Aruba" },
            { "timezone.excity.America/Bahia", "Baija" },
            { "timezone.excity.America/Belem", "Belenas" },
            { "timezone.excity.America/Boise", "Boisis" },
            { "timezone.excity.America/Jujuy", "Chuchujus" },
            { "timezone.excity.America/Sitka", "Sitka" },
            { "timezone.excity.America/Thule", "Kanakas" },
            { "timezone.excity.Asia/Ashgabat", "A\u0161chabadas" },
            { "timezone.excity.Asia/Damascus", "Damaskas" },
            { "timezone.excity.Asia/Dushanbe", "Du\u0161anb\u0117" },
            { "timezone.excity.Asia/Jayapura", "D\u017eajapura" },
            { "timezone.excity.Asia/Katmandu", "Katmandu" },
            { "timezone.excity.Asia/Khandyga", "Chandyga" },
            { "timezone.excity.Asia/Makassar", "Makasaras" },
            { "timezone.excity.Asia/Qostanay", "Kostanajus" },
            { "timezone.excity.Asia/Sakhalin", "Sachalinas" },
            { "timezone.excity.Asia/Shanghai", "\u0160anchajus" },
            { "timezone.excity.Asia/Tashkent", "Ta\u0161kentas" },
            { "timezone.excity.Asia/Ust-Nera", "Ust Nera" },
            { "timezone.excity.Europe/Athens", "At\u0117nai" },
            { "timezone.excity.Europe/Berlin", "Berlynas" },
            { "timezone.excity.Europe/Dublin", "Dublinas" },
            { "timezone.excity.Europe/Jersey", "D\u017eersis" },
            { "timezone.excity.Europe/Lisbon", "Lisabona" },
            { "timezone.excity.Europe/London", "Londonas" },
            { "timezone.excity.Europe/Madrid", "Madridas" },
            { "timezone.excity.Europe/Monaco", "Monakas" },
            { "timezone.excity.Europe/Moscow", "Maskva" },
            { "timezone.excity.Europe/Prague", "Praha" },
            { "timezone.excity.Europe/Samara", "Samara" },
            { "timezone.excity.Europe/Skopje", "Skopj\u0117" },
            { "timezone.excity.Europe/Tirane", "Tirana" },
            { "timezone.excity.Europe/Vienna", "Viena" },
            { "timezone.excity.Europe/Warsaw", "Var\u0161uva" },
            { "timezone.excity.Europe/Zagreb", "Zagrebas" },
            { "timezone.excity.Europe/Zurich", "Ciurichas" },
            { "timezone.excity.Indian/Chagos", "\u010cagosas" },
            { "timezone.excity.Indian/Comoro", "Komoras" },
            { "timezone.excity.Pacific/Efate", "Efat\u0117" },
            { "timezone.excity.Pacific/Nauru", "Nauru" },
            { "timezone.excity.Pacific/Palau", "Palau" },
            { "America/Argentina/Rio_Gallegos", Argentina },
            { "America/North_Dakota/New_Salem", America_Central },
            { "timezone.excity.Africa/Abidjan", "Abid\u017eanas" },
            { "timezone.excity.Africa/Algiers", "Al\u017eyras" },
            { "timezone.excity.Africa/Conakry", "Konakris" },
            { "timezone.excity.Africa/Kampala", "Kampala" },
            { "timezone.excity.Africa/Mbabane", "Mbaban\u0117" },
            { "timezone.excity.Africa/Nairobi", "Nairobis" },
            { "timezone.excity.Africa/Tripoli", "Tripolis" },
            { "timezone.excity.America/Belize", "Belizas" },
            { "timezone.excity.America/Bogota", "Bogota" },
            { "timezone.excity.America/Cancun", "Kank\u016bnas" },
            { "timezone.excity.America/Cayman", "Kaimanas" },
            { "timezone.excity.America/Cuiaba", "Kujaba" },
            { "timezone.excity.America/Dawson", "Dosonas" },
            { "timezone.excity.America/Denver", "Denveris" },
            { "timezone.excity.America/Guyana", "Gvajana" },
            { "timezone.excity.America/Havana", "Havana" },
            { "timezone.excity.America/Inuvik", "Inuvikas" },
            { "timezone.excity.America/Juneau", "D\u017eunas" },
            { "timezone.excity.America/La_Paz", "La Pasas" },
            { "timezone.excity.America/Maceio", "Masejo" },
            { "timezone.excity.America/Manaus", "Manausas" },
            { "timezone.excity.America/Merida", "Merida" },
            { "timezone.excity.America/Nassau", "Nasau" },
            { "timezone.excity.America/Panama", "Panama" },
            { "timezone.excity.America/Recife", "Resif\u0117" },
            { "timezone.excity.America/Regina", "Red\u017eina" },
            { "timezone.excity.Asia/Famagusta", "Famagusta" },
            { "timezone.excity.Asia/Hong_Kong", "Honkongas" },
            { "timezone.excity.Asia/Jerusalem", "Jeruzal\u0117" },
            { "timezone.excity.Asia/Kamchatka", "Kam\u010diatka" },
            { "timezone.excity.Asia/Pontianak", "Pontianakas" },
            { "timezone.excity.Asia/Pyongyang", "Pchenjanas" },
            { "timezone.excity.Asia/Qyzylorda", "Kzyl-Orda" },
            { "timezone.excity.Asia/Samarkand", "Samarkandas" },
            { "timezone.excity.Asia/Singapore", "Singap\u016bras" },
            { "timezone.excity.Asia/Vientiane", "Vientianas" },
            { "timezone.excity.Europe/Andorra", "Andora" },
            { "timezone.excity.Europe/Saratov", "Saratovas" },
            { "timezone.excity.Europe/Tallinn", "Talinas" },
            { "timezone.excity.Europe/Vatican", "Vatikanas" },
            { "timezone.excity.Europe/Vilnius", "Vilnius" },
            { "timezone.excity.Indian/Mayotte", "Majotas" },
            { "timezone.excity.Indian/Reunion", "Reunjonas" },
            { "timezone.excity.Pacific/Easter", "Velyk\u0173 sala" },
            { "timezone.excity.Pacific/Kosrae", "Kosraj\u0117" },
            { "timezone.excity.Pacific/Majuro", "Mad\u017e\u016bras" },
            { "timezone.excity.Pacific/Midway", "Midv\u0117jus" },
            { "timezone.excity.Pacific/Noumea", "Num\u0117ja" },
            { "timezone.excity.Pacific/Ponape", "Ponap\u0117" },
            { "timezone.excity.Pacific/Saipan", "Saipanas" },
            { "timezone.excity.Pacific/Tahiti", "Taitis" },
            { "timezone.excity.Pacific/Tarawa", "Tarava" },
            { "timezone.excity.Pacific/Wallis", "Volisas" },
            { "timezone.excity.Africa/Blantyre", "Blantairas" },
            { "timezone.excity.Africa/Djibouti", "D\u017eibutis" },
            { "timezone.excity.Africa/El_Aaiun", "al Aj\u016bnas" },
            { "timezone.excity.Africa/Freetown", "Fritaunas" },
            { "timezone.excity.Africa/Gaborone", "Gaboronas" },
            { "timezone.excity.Africa/Khartoum", "Chartumas" },
            { "timezone.excity.Africa/Kinshasa", "Kin\u0161asa" },
            { "timezone.excity.Africa/Monrovia", "Monrovija" },
            { "timezone.excity.Africa/Ndjamena", "Nd\u017eamena" },
            { "timezone.excity.Africa/Sao_Tome", "San Tom\u0117" },
            { "timezone.excity.Africa/Windhoek", "Vindhukas" },
            { "timezone.excity.America/Antigua", "Antigva" },
            { "timezone.excity.America/Caracas", "Karakasas" },
            { "timezone.excity.America/Cayenne", "Kajenas" },
            { "timezone.excity.America/Chicago", "\u010cikaga" },
            { "timezone.excity.America/Cordoba", "Kordoba" },
            { "timezone.excity.America/Creston", "Krestonas" },
            { "timezone.excity.America/Curacao", "Kiurasao" },
            { "timezone.excity.America/Detroit", "Detroitas" },
            { "timezone.excity.America/Godthab", "N\u016bkas" },
            { "timezone.excity.America/Grenada", "Grenada" },
            { "timezone.excity.America/Halifax", "Halifaksas" },
            { "timezone.excity.America/Iqaluit", "Ikaluitas" },
            { "timezone.excity.America/Jamaica", "Jamaika" },
            { "timezone.excity.America/Managua", "Managva" },
            { "timezone.excity.America/Marigot", "Marigo" },
            { "timezone.excity.America/Mendoza", "Mendosa" },
            { "timezone.excity.America/Moncton", "Monktonas" },
            { "timezone.excity.America/Nipigon", "Nipigonas" },
            { "timezone.excity.America/Noronha", "Noronja" },
            { "timezone.excity.America/Ojinaga", "Ochinaga" },
            { "timezone.excity.America/Phoenix", "Finiksas" },
            { "timezone.excity.America/Tijuana", "Tichuana" },
            { "timezone.excity.America/Toronto", "Torontas" },
            { "timezone.excity.America/Tortola", "Tortola" },
            { "timezone.excity.America/Yakutat", "Jakutatas" },
            { "timezone.excity.Asia/Choibalsan", "\u010coibalsanas" },
            { "timezone.excity.Asia/Phnom_Penh", "Pnompenis" },
            { "timezone.excity.Atlantic/Azores", "Azorai" },
            { "timezone.excity.Atlantic/Canary", "Kanar\u0173 salos" },
            { "timezone.excity.Atlantic/Faeroe", "Farerai" },
            { "timezone.excity.Australia/Eucla", "Jukla" },
            { "timezone.excity.Australia/Perth", "Pertas" },
            { "timezone.excity.Europe/Belgrade", "Belgradas" },
            { "timezone.excity.Europe/Brussels", "Briuselis" },
            { "timezone.excity.Europe/Budapest", "Budape\u0161tas" },
            { "timezone.excity.Europe/Busingen", "Biusingenas" },
            { "timezone.excity.Europe/Chisinau", "Ki\u0161iniovas" },
            { "timezone.excity.Europe/Guernsey", "Gernsis" },
            { "timezone.excity.Europe/Helsinki", "Helsinkis" },
            { "timezone.excity.Europe/Istanbul", "Stambulas" },
            { "timezone.excity.Europe/Sarajevo", "Sarajevas" },
            { "timezone.excity.Europe/Uzhgorod", "U\u017ehorodas" },
            { "timezone.excity.Indian/Maldives", "Maldyvai" },
            { "timezone.excity.Pacific/Chatham", "\u010catamas" },
            { "timezone.excity.Pacific/Fakaofo", "Fakaofas" },
            { "timezone.excity.Pacific/Gambier", "Gambyras" },
            { "timezone.excity.Pacific/Norfolk", "Norfolkas" },
            { "timezone.excity.Africa/Bujumbura", "Bu\u017eumb\u016bra" },
            { "timezone.excity.Africa/Mogadishu", "Mogadi\u0161as" },
            { "timezone.excity.America/Anguilla", "Angilija" },
            { "timezone.excity.America/Asuncion", "Asunsjonas" },
            { "timezone.excity.America/Barbados", "Barbadosas" },
            { "timezone.excity.America/Dominica", "Dominika" },
            { "timezone.excity.America/Edmonton", "Edmontonas" },
            { "timezone.excity.America/Eirunepe", "Eirunep\u0117" },
            { "timezone.excity.America/Mazatlan", "Masatlanas" },
            { "timezone.excity.America/Miquelon", "Mikelonas" },
            { "timezone.excity.America/New_York", "Niujorkas" },
            { "timezone.excity.America/Resolute", "Resolutas" },
            { "timezone.excity.America/Santarem", "Santarenas" },
            { "timezone.excity.America/Santiago", "Santjagas" },
            { "timezone.excity.America/St_Johns", "Sent D\u017eonsas" },
            { "timezone.excity.America/St_Kitts", "Sent Kitsas" },
            { "timezone.excity.America/St_Lucia", "Sent Lusija" },
            { "timezone.excity.America/Winnipeg", "Vinipegas" },
            { "timezone.excity.Antarctica/Casey", "Keisis" },
            { "timezone.excity.Antarctica/Davis", "Deivisas" },
            { "timezone.excity.Antarctica/Syowa", "Siova" },
            { "timezone.excity.Antarctica/Troll", "Trolis" },
            { "timezone.excity.Asia/Krasnoyarsk", "Krasnojarskas" },
            { "timezone.excity.Asia/Novosibirsk", "Novosibirskas" },
            { "timezone.excity.Asia/Ulaanbaatar", "Ulan Batoras" },
            { "timezone.excity.Asia/Vladivostok", "Vladivostokas" },
            { "timezone.excity.Atlantic/Bermuda", "Bermuda" },
            { "timezone.excity.Atlantic/Madeira", "Madeira" },
            { "timezone.excity.Atlantic/Stanley", "Stenlis" },
            { "timezone.excity.Australia/Currie", "Karis" },
            { "timezone.excity.Australia/Darwin", "Darvinas" },
            { "timezone.excity.Australia/Hobart", "Hobartas" },
            { "timezone.excity.Australia/Sydney", "Sidn\u0117jus" },
            { "timezone.excity.Europe/Amsterdam", "Amsterdamas" },
            { "timezone.excity.Europe/Astrakhan", "Astrachan\u0117" },
            { "timezone.excity.Europe/Bucharest", "Bukare\u0161tas" },
            { "timezone.excity.Europe/Gibraltar", "Gibraltaras" },
            { "timezone.excity.Europe/Ljubljana", "Liubliana" },
            { "timezone.excity.Europe/Mariehamn", "Marianhamina" },
            { "timezone.excity.Europe/Podgorica", "Podgorica" },
            { "timezone.excity.Europe/Stockholm", "Stokholmas" },
            { "timezone.excity.Europe/Ulyanovsk", "Uljanovskas" },
            { "timezone.excity.Europe/Volgograd", "Volgogradas" },
            { "timezone.excity.Indian/Christmas", "Kal\u0117d\u0173 Sala" },
            { "timezone.excity.Indian/Kerguelen", "Kergelenas" },
            { "timezone.excity.Indian/Mauritius", "Mauricijus" },
            { "timezone.excity.Pacific/Auckland", "Oklandas" },
            { "timezone.excity.Pacific/Funafuti", "Funafutis" },
            { "timezone.excity.Pacific/Honolulu", "Honolulu" },
            { "timezone.excity.Pacific/Johnston", "D\u017eonstonas" },
            { "timezone.excity.Pacific/Pitcairn", "Pitkerno sala" },
            { "timezone.excity.Africa/Casablanca", "Kasablanka" },
            { "timezone.excity.Africa/Libreville", "Librevilis" },
            { "timezone.excity.Africa/Lubumbashi", "Lubumba\u0161is" },
            { "timezone.excity.Africa/Nouakchott", "Nuak\u0161otas" },
            { "timezone.excity.Africa/Porto-Novo", "Porto Novas" },
            { "timezone.excity.America/Anchorage", "Ankorid\u017eas" },
            { "timezone.excity.America/Araguaina", "Aragvajana" },
            { "timezone.excity.America/Boa_Vista", "Bua Vista" },
            { "timezone.excity.America/Catamarca", "Katamarka" },
            { "timezone.excity.America/Chihuahua", "\u010cihuahua" },
            { "timezone.excity.America/Fortaleza", "Fortaleza" },
            { "timezone.excity.America/Glace_Bay", "Gleis B\u0117jus" },
            { "timezone.excity.America/Goose_Bay", "Gus B\u0117jus" },
            { "timezone.excity.America/Guatemala", "Gvatemala" },
            { "timezone.excity.America/Guayaquil", "Gvajakilis" },
            { "timezone.excity.America/Matamoros", "Matamorosas" },
            { "timezone.excity.America/Menominee", "Menominis" },
            { "timezone.excity.America/Monterrey", "Monter\u0117jus" },
            { "timezone.excity.America/Sao_Paulo", "San Paulas" },
            { "timezone.excity.America/St_Thomas", "Sent Tomasas" },
            { "timezone.excity.America/Vancouver", "Vankuveris" },
            { "timezone.excity.Antarctica/Mawson", "Mosonas" },
            { "timezone.excity.Antarctica/Palmer", "Palmeris" },
            { "timezone.excity.Antarctica/Vostok", "Vostokas" },
            { "timezone.excity.Asia/Kuala_Lumpur", "Kvala Lump\u016bras" },
            { "timezone.excity.Asia/Novokuznetsk", "Novokuzneckas" },
            { "timezone.excity.Europe/Bratislava", "Bratislava" },
            { "timezone.excity.Europe/Copenhagen", "Kopenhaga" },
            { "timezone.excity.Europe/Luxembourg", "Liuksemburgas" },
            { "timezone.excity.Europe/San_Marino", "San Marinas" },
            { "timezone.excity.Europe/Simferopol", "Simferopolis" },
            { "timezone.excity.Europe/Zaporozhye", "Zaporo\u017e\u0117" },
            { "timezone.excity.Pacific/Enderbury", "Enderburis" },
            { "timezone.excity.Pacific/Galapagos", "Galapagai" },
            { "timezone.excity.Pacific/Kwajalein", "Kvad\u017ealeinas" },
            { "timezone.excity.Pacific/Marquesas", "Markizo salos" },
            { "timezone.excity.Pacific/Pago_Pago", "Pago Pagas" },
            { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
            { "timezone.excity.Pacific/Tongatapu", "Tongatapu" },
            { "timezone.excity.Africa/Addis_Ababa", "Adis Abeba" },
            { "timezone.excity.Africa/Brazzaville", "Brazavilis" },
            { "timezone.excity.Africa/Ouagadougou", "Vagadugu" },
            { "timezone.excity.America/Costa_Rica", "Kosta Rika" },
            { "timezone.excity.America/Grand_Turk", "Grand Terkas" },
            { "timezone.excity.America/Guadeloupe", "Gvadalup\u0117" },
            { "timezone.excity.America/Hermosillo", "Hermosiljas" },
            { "timezone.excity.America/Kralendijk", "Kralendeikas" },
            { "timezone.excity.America/Louisville", "Luisvilis" },
            { "timezone.excity.America/Martinique", "Martinika" },
            { "timezone.excity.America/Metlakatla", "Metlakatla" },
            { "timezone.excity.America/Montevideo", "Montevid\u0117jas" },
            { "timezone.excity.America/Montserrat", "Montseratas" },
            { "timezone.excity.America/Paramaribo", "Paramaribas" },
            { "timezone.excity.America/Rio_Branco", "Rio Brankas" },
            { "timezone.excity.America/St_Vincent", "Sent Vincentas" },
            { "timezone.excity.America/Whitehorse", "Vaithorsas" },
            { "timezone.excity.Antarctica/McMurdo", "Makmerdas" },
            { "timezone.excity.Antarctica/Rothera", "Rotera" },
            { "timezone.excity.Asia/Srednekolymsk", "Srednekolymskas" },
            { "timezone.excity.Asia/Yekaterinburg", "Jekaterinburgas" },
            { "timezone.excity.Atlantic/Reykjavik", "Reikjavikas" },
            { "timezone.excity.Atlantic/St_Helena", "Sent Helena" },
            { "timezone.excity.Australia/Adelaide", "Adelaid\u0117" },
            { "timezone.excity.Australia/Brisbane", "Brisbanas" },
            { "timezone.excity.Australia/Lindeman", "Lindemanas" },
            { "timezone.excity.Europe/Isle_of_Man", "Meno sala" },
            { "timezone.excity.Europe/Kaliningrad", "Kaliningradas" },
            { "timezone.excity.Pacific/Kiritimati", "Kiritimatis" },
            { "timezone.excity.Africa/Johannesburg", "Johanesburgas" },
            { "timezone.excity.America/El_Salvador", "Salvadoras" },
            { "timezone.excity.America/Fort_Nelson", "Fort Nelsonas" },
            { "timezone.excity.America/Los_Angeles", "Los And\u017eelas" },
            { "timezone.excity.America/Mexico_City", "Meksikas" },
            { "timezone.excity.America/Pangnirtung", "Pangnirtungas" },
            { "timezone.excity.America/Porto_Velho", "Porto Veljas" },
            { "timezone.excity.America/Puerto_Rico", "Puerto Rikas" },
            { "timezone.excity.America/Rainy_River", "Reini Riveris" },
            { "timezone.excity.America/Tegucigalpa", "Tegusigalpa" },
            { "timezone.excity.America/Thunder_Bay", "Tander B\u0117jus" },
            { "timezone.excity.America/Yellowknife", "Jelounaifas" },
            { "timezone.excity.Arctic/Longyearbyen", "Longjyrbienas" },
            { "timezone.excity.Atlantic/Cape_Verde", "\u017daliasis Ky\u0161ulys" },
            { "timezone.excity.Australia/Lord_Howe", "Lordo Hau sala" },
            { "timezone.excity.Australia/Melbourne", "Melburnas" },
            { "timezone.excity.Indian/Antananarivo", "Antananaryvas" },
            { "timezone.excity.Pacific/Guadalcanal", "Gvadalkanalis" },
            { "timezone.excity.Africa/Dar_es_Salaam", "Dar es Salamas" },
            { "timezone.excity.America/Blanc-Sablon", "Blan\u010d Sablonas" },
            { "timezone.excity.America/Buenos_Aires", "Buenos Air\u0117s" },
            { "timezone.excity.America/Campo_Grande", "Kampo Grand\u0117" },
            { "timezone.excity.America/Danmarkshavn", "Danmarkshaunas" },
            { "timezone.excity.America/Dawson_Creek", "Doson Krikas" },
            { "timezone.excity.America/Indiana/Knox", "Noksas, Indiana" },
            { "timezone.excity.America/Indianapolis", "Indianapolis" },
            { "timezone.excity.America/Punta_Arenas", "Punta Arenasas" },
            { "timezone.excity.America/Rankin_Inlet", "Rankin Inletas" },
            { "timezone.excity.America/Santa_Isabel", "Santa Izabel\u0117" },
            { "timezone.excity.America/Scoresbysund", "Itokortormitas" },
            { "timezone.excity.Antarctica/Macquarie", "Makvoris" },
            { "timezone.excity.Pacific/Bougainville", "Bugenvilis" },
            { "timezone.excity.Pacific/Port_Moresby", "Port Morsbis" },
            { "timezone.excity.America/Cambridge_Bay", "Keimbrid\u017e B\u0117jus" },
            { "timezone.excity.America/Coral_Harbour", "Atikokanas" },
            { "timezone.excity.America/Indiana/Vevay", "Vivis, Indiana" },
            { "timezone.excity.America/Lower_Princes", "\u017demutinis Prinses Kvorteris" },
            { "timezone.excity.America/Port_of_Spain", "Port of Speinas" },
            { "timezone.excity.America/Santo_Domingo", "Santo Domingas" },
            { "timezone.excity.America/St_Barthelemy", "Sen Bartelemi" },
            { "timezone.excity.America/Swift_Current", "Svift Karentas" },
            { "timezone.excity.Australia/Broken_Hill", "Broken Hilis" },
            { "timezone.excity.America/Bahia_Banderas", "Bahia Banderasas" },
            { "timezone.excity.America/Port-au-Prince", "Port o Prensas" },
            { "timezone.excity.Atlantic/South_Georgia", "Piet\u0173 D\u017eord\u017eija" },
            { "timezone.excity.America/Argentina/Salta", "Saltas" },
            { "timezone.excity.America/Indiana/Marengo", "Marengas, Indiana" },
            { "timezone.excity.America/Indiana/Winamac", "Vinamakas, Indiana" },
            { "timezone.excity.America/Argentina/Tucuman", "Tukumanas" },
            { "timezone.excity.America/Argentina/Ushuaia", "U\u0161uaja" },
            { "timezone.excity.America/Indiana/Tell_City", "Tel Sitis, Indiana" },
            { "timezone.excity.America/Indiana/Vincennes", "Vinsenas, Indiana" },
            { "timezone.excity.Antarctica/DumontDUrville", "Diumonas d\u2019Urvilis" },
            { "timezone.excity.America/Argentina/La_Rioja", "La Riocha" },
            { "timezone.excity.America/Argentina/San_Juan", "San Chuanas" },
            { "timezone.excity.America/Argentina/San_Luis", "Sent Luisas" },
            { "timezone.excity.America/Indiana/Petersburg", "Pitersbergas, Indiana" },
            { "timezone.excity.America/Kentucky/Monticello", "Montiselas, Kentukis" },
            { "timezone.excity.America/North_Dakota/Beulah", "Bjula, \u0160iaur\u0117s Dakota" },
            { "timezone.excity.America/North_Dakota/Center", "Senteris, \u0160iaur\u0117s Dakota" },
            { "timezone.excity.America/Argentina/Rio_Gallegos", "Rio Galjegosas" },
            { "timezone.excity.America/North_Dakota/New_Salem", "Niu Seilemas, \u0160iaur\u0117s Dakota" },
        };
        return data;
    }
}
